==> homekit-0.9.tar.gz: homekit-0.9/homekit/model/services/bhslightbulb_service.py <==
#
# Copyright 2018 Joachim Lusiardi
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from homekit.model import get_id
from homekit.model.characteristics import BrightnessCharacteristicMixin, OnCharacteristicMixin, \
    HueCharacteristicMixin, SaturationCharacteristicMixin
from homekit.model.services.service_types import ServicesTypes
from homekit.model.services.abstract_service import AbstractService


class BHSLightBulbService(AbstractService, OnCharacteristicMixin, BrightnessCharacteristicMixin,
                          HueCharacteristicMixin, SaturationCharacteristicMixin):
    """
    Defined on page 217; Light bulb that supports color selection via Brightness, Hue and Saturation
    """

    def __init__(self):
        AbstractService.__init__(self, ServicesTypes.get_uuid('public.hap.service.lightbulb'), get_id())
        OnCharacteristicMixin.__init__(self, get_id())
        BrightnessCharacteristicMixin.__init__(self, get_id())
        HueCharacteristicMixin.__init__(self, get_id())
        SaturationCharacteristicMixin.__init__(self, get_id())

==> homekit-0.12.3.tar.gz: homekit-0.12.3/homekit/model/services/bhslightbulb_service.py <==
#
# Copyright 2018 Joachim Lusiardi
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from homekit.model import get_id
from homekit.model.characteristics import OnCharacteristicMixin, BrightnessCharacteristicMixin, HueCharacteristicMixin, \
    SaturationCharacteristicMixin
from homekit.model.services import ServicesTypes, AbstractService


class BHSLightBulbService(AbstractService, OnCharacteristicMixin, BrightnessCharacteristicMixin,
                          HueCharacteristicMixin, SaturationCharacteristicMixin):
    """
    Defined on page 217; Light bulb that supports color selection via Brightness, Hue and Saturation
    """

    def __init__(self):
        AbstractService.__init__(self, ServicesTypes.get_uuid('public.hap.service.lightbulb'), get_id())
        OnCharacteristicMixin.__init__(self, get_id())
        BrightnessCharacteristicMixin.__init__(self, get_id())
        HueCharacteristicMixin.__init__(self, get_id())
        SaturationCharacteristicMixin.__init__(self, get_id())
